/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.filing.constructionStage.mapper;

import com.jeeplus.core.persistence.BaseMapper;
import com.jeeplus.core.persistence.annotation.MyBatisMapper;
import com.jeeplus.modules.filing.constructionStage.entity.*;

import javax.ejb.Startup;
import java.util.List;

/**
 * 核准阶段MAPPER接口
 * @author qy
 * @version 2021-03-25
 */
@MyBatisMapper
public interface ConstructionStageMapper extends BaseMapper<ConstructionStage> {
    List<ConstructionStage> findChildList(ConstructionStage entity);

    Integer findByCode(ConstructionStage entity);

    Integer findCode(String projectCode);

    /**
     * 通过id集合查询出所有符合条件的项目基础信息
     */
    List<ConstructionStage> findByIdList(List<String> idList);

    /**
     * 通过项目id查询出所有的项目信息
     * */
    List<ConstructionStage> findAll(List<String> idList);

    void insertStartUp(StartUP startUP);

    void updateStartUp(StartUP startUP);

    void insertProjectSchedule(ProjectSchedule entity);

    void updateProjectSchedule(ProjectSchedule entity);

    void insertCostManagment(CostManagment entity);

    void updateCostManagment(CostManagment entity);

    void insertProjectOther(ProjectOther entity);

    void updateProjectOther(ProjectOther entity);

    void insertQulityAssurance(QulityAssurance entity);

    void updateQulityAssurance(QulityAssurance entity);

    void insertSafetyQuality(SafetyQuality entity);

    void updateSafetyQuality(SafetyQuality entity);

    void insertSecurityManagment(SecurityManagment entity);

    void updateSecurityManagment(SecurityManagment entity);
}